@@ -52,6 +52,11 @@ class RestAPIExampleAsync:
     """
     result_queue: Optional[asyncio.Queue] = None
 
+    @web_api(content_type='text/plain', method=RestMethod.GET, is_constructor=True, uuid_param='uuid')
+    @staticmethod
+    async def explicit_constructor(uuid: str) -> "RestAPIExampleAsync":
+        return RestAPIExampleAsync()
+
     @web_api(content_type='text/plain', method=RestMethod.GET)
     @staticmethod
     async def api_get_basic(param1: int, param2: bool, param3: float, param4: str = "text", param5: Dict[str, float] = {'f1': 1.0, 'f2': 2.0}) -> str:
@@ -202,12 +207,12 @@ class TestJavascriptGenerator:
             return result
 
         try:
-            completed, _ = await asyncio.wait([app.start(), launch_browser()], timeout=10000000, return_when=asyncio.FIRST_COMPLETED)
+            completed, _ = await asyncio.wait([app.start(), launch_browser()], timeout=100000, return_when=asyncio.FIRST_COMPLETED)
             results = [c.result() for c in completed if c is not None]
         except Exception as e:
             assert False, f"Exception processing javascript results: {traceback.format_exc()}"
         if any([isinstance(r, Exception) for r in results]):
             assert False, "At least one javascript test failed. See browser window for details"
         assert results[0] == "PASSED", \
-            "FAILED JAVSSCRIPT TESTS FOUND: \n" + \
+            "FAILED JAVASCRIPT TESTS FOUND: \n" + \
             "\n".join([f"{test}: {msg}" for test, msg in json.loads(results[0]).items()])
